/* OptDlg.c - File contains all regarding the Options Dialog */

#define WIN32_LEAN_AND_MEAN
#include <windows.h>
#include <commctrl.h>
#include <stdio.h>
#include "unzip32dll.h"
#include "resource.h"
#include "Dialog.h"

extern HINSTANCE        g_hInst;
extern HINSTANCE        hUnzip32Dll;
extern _DLL_UNZIP       windll_unzip;
extern _DLL_VERSION     lUzpVersion;   /* UzpVersion already defined in unzip.h as a funktion */
extern USERFUNCTIONS    UserFunctions;
extern ZIPMessage       *Messages;
extern ZIPEntry         *Entries;
extern UzpVer           UnzipVersion;

BOOL APIENTRY OptionsDlgProc(HWND hwndDlg,UINT message,WPARAM wParam,LPARAM lParam)
{   ZIPShellDlgData *pDlgData;
    HWND            hWnd;
    int             i;
    char            *format,*buffer;
    
    switch(message)
    {   case    WM_INITDIALOG:
            SetWindowLong(hwndDlg,GWL_USERDATA,lParam);
            pDlgData=(ZIPShellDlgData*)lParam;

            if(pDlgData->ColFlags&COL_SIZE)
                CheckDlgButton(hwndDlg,IDC_OPTIONS_SIZE,BST_CHECKED);

            if(pDlgData->ColFlags&COL_CSIZE)
                CheckDlgButton(hwndDlg,IDC_OPTIONS_CSIZE,BST_CHECKED);

            if(pDlgData->ColFlags&COL_DATE)
                CheckDlgButton(hwndDlg,IDC_OPTIONS_DATE,BST_CHECKED);

            if(pDlgData->ColFlags&COL_TIME)
                CheckDlgButton(hwndDlg,IDC_OPTIONS_TIME,BST_CHECKED);

            if(pDlgData->ColFlags&COL_CRC)
                CheckDlgButton(hwndDlg,IDC_OPTIONS_CRC,BST_CHECKED);

            if(pDlgData->ColFlags&COL_METHOD)
                CheckDlgButton(hwndDlg,IDC_OPTIONS_METHOD,BST_CHECKED);

            if(GetUnzipDll())
                UnzipVersion= *lUzpVersion();

            hWnd=GetDlgItem(hwndDlg,IDC_VERSION);
            format=(char*)malloc(256*sizeof(char));
            i=min(GetWindowTextLength(hWnd)+1,256);
            buffer=format+GetWindowText(hWnd,format,i)+1;
            i=sprintf(buffer,format,ZIPSHELLEXT_VER_MAJOR,ZIPSHELLEXT_VER_MINOR);
            SetWindowText(hWnd,buffer);

            hWnd=GetDlgItem(hwndDlg,IDC_VERSION_DATE);
            i=min(GetWindowTextLength(hWnd)+1,256);
            buffer=format+GetWindowText(hWnd,format,i)+1;
            i=sprintf(buffer,format,__DATE__);
            SetWindowText(hWnd,buffer);

            hWnd=GetDlgItem(hwndDlg,IDC_OPTIONS_VERSION);
            i=min(GetWindowTextLength(hWnd)+1,256);
            buffer=format+GetWindowText(hWnd,format,i)+1;
            i=sprintf(buffer,format,UnzipVersion.windll.major,UnzipVersion.windll.minor,UnzipVersion.windll.patchlevel);
            SetWindowText(hWnd,buffer);

            hWnd=GetDlgItem(hwndDlg,IDC_OPTIONS_DLLDATE);
            i=min(GetWindowTextLength(hWnd)+1,256);
            buffer=format+GetWindowText(hWnd,format,i)+1;
            i=sprintf(buffer,format,UnzipVersion.date);
            SetWindowText(hWnd,buffer);

            if(UnzipVersion.flag&0x1)   /* bit 0: is_beta   bit 1: uses_zlib */
            {   
                hWnd=GetDlgItem(hwndDlg,IDC_OPTIONS_BETA);
                SetWindowLong(hWnd,GWL_STYLE,WS_VISIBLE|GetWindowLong(hWnd,GWL_STYLE));
                i=min(GetWindowTextLength(hWnd)+1,256);
                buffer=format+GetWindowText(hWnd,format,i)+1;
                i=sprintf(buffer,format,UnzipVersion.betalevel);
                SetWindowText(hWnd,buffer);
            }

            if(UnzipVersion.flag&0x10)
            {
                hWnd=GetDlgItem(hwndDlg,IDC_OPTIONS_ZLIB);
                SetWindowLong(hWnd,GWL_STYLE,WS_VISIBLE|GetWindowLong(hWnd,GWL_STYLE));
                i=min(GetWindowTextLength(hWnd)+1,256);
                buffer=format+GetWindowText(hWnd,format,i)+1;
                i=sprintf(buffer,format,UnzipVersion.betalevel);
                SetWindowText(hWnd,buffer);
            }

            free(format);
        break;
        case    WM_CLOSE:
            EndDialog(hwndDlg,IDCANCEL);
        break;
        case    WM_COMMAND:
            switch(LOWORD(wParam))
            {   case    IDOK:
                    pDlgData=(ZIPShellDlgData*)GetWindowLong(hwndDlg,GWL_USERDATA);
                
                    pDlgData->ColFlags&=~(COL_SIZE|COL_CSIZE|COL_DATE|COL_CRC|COL_TIME|COL_METHOD);

                    if(BST_UNCHECKED!=IsDlgButtonChecked(hwndDlg,IDC_OPTIONS_SIZE))
                        pDlgData->ColFlags|=COL_SIZE;

                    if(BST_UNCHECKED!=IsDlgButtonChecked(hwndDlg,IDC_OPTIONS_CSIZE))
                        pDlgData->ColFlags|=COL_CSIZE;

                    if(BST_UNCHECKED!=IsDlgButtonChecked(hwndDlg,IDC_OPTIONS_DATE))
                        pDlgData->ColFlags|=COL_DATE;

                    if(BST_UNCHECKED!=IsDlgButtonChecked(hwndDlg,IDC_OPTIONS_CRC))
                        pDlgData->ColFlags|=COL_CRC;

                    if(BST_UNCHECKED!=IsDlgButtonChecked(hwndDlg,IDC_OPTIONS_TIME))
                        pDlgData->ColFlags|=COL_TIME;

                    if(BST_UNCHECKED!=IsDlgButtonChecked(hwndDlg,IDC_OPTIONS_METHOD))
                        pDlgData->ColFlags|=COL_METHOD;

                    AdjColumns(hwndDlg);
                case    IDCANCEL:
                    EndDialog(hwndDlg,LOWORD(wParam));
                break;
                case    IDC_OPTIONS_EXTERN:
                    if(BST_UNCHECKED!=IsDlgButtonChecked(hwndDlg,IDC_OPTIONS_EXTERN))
                        SendDlgItemMessage(hwndDlg,IDC_OPTION_VIEWER,WM_ENABLE,TRUE,0);
                    else
                        SendDlgItemMessage(hwndDlg,IDC_OPTION_VIEWER,WM_ENABLE,FALSE,0);
                break;
                default:
                    return(FALSE);
            }
            break;
        default:
            return(FALSE);
    }
    return(TRUE);
}
